pub struct PlotSeriesSpec {
pub name: String,
pub dtype: DType,
pub index: Vec<IndexLabel>,
pub values: Vec<Scalar>,
pub group_key: Option<Vec<Scalar>>,
}Expand description
One logical series ready for a future plotting backend.
Fields
name: Stringdtype: DTypeindex: Vec<IndexLabel>values: Vec<Scalar>group_key: Option<Vec<Scalar>>Trait Implementations
Sourceimpl Clone for PlotSeriesSpec
impl Clone for PlotSeriesSpec
Sourcefn clone(&self) -> PlotSeriesSpec
fn clone(&self) -> PlotSeriesSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlotSeriesSpec
impl Debug for PlotSeriesSpec
Sourceimpl<'de> Deserialize<'de> for PlotSeriesSpec
impl<'de> Deserialize<'de> for PlotSeriesSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PlotSeriesSpec
impl PartialEq for PlotSeriesSpec
Sourcefn eq(&self, other: &PlotSeriesSpec) -> bool
fn eq(&self, other: &PlotSeriesSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PlotSeriesSpec
impl Serialize for PlotSeriesSpec
impl StructuralPartialEq for PlotSeriesSpec